@@ -14,10 +14,6 @@ except ImportError:
     from collections import Mapping
 
 import csv
-
-from .. import data
-from ..exceptions import MatchingIDNotFound
-
 from typing import (
     Any,
     Callable,
@@ -32,6 +28,10 @@ from typing import (
     overload,
 )
 
+from .. import data
+from ..exceptions import MatchingIDNotFound
+from ..typing import HasOpen, HasRead
+
 A = TypeVar("A")
 B = TypeVar("B")
 A_conv = Callable[[str], Union[A, int]]
@@ -77,7 +77,7 @@ class BiMap(Generic[A, B]):
         Advanced usage:
         >>> # Either pass a file name or a file object
         >>> from particle import data
-        >>> filename = data.open_text(data, 'pdgid_to_pythiaid.csv')
+        >>> filename = data.basepath / "pdgid_to_pythiaid.csv"
         >>> bimap = BiMap(PDGID, PythiaID, filename=filename)
         """
 
@@ -89,22 +89,23 @@ class BiMap(Generic[A, B]):
 
         if filename is None:
             filename = "{a}_to_{b}.csv".format(a=name_A.lower(), b=name_B.lower())
-            file_object = data.open_text(data, filename)
-        elif hasattr(filename, "read"):
+            file_object = data.basepath.joinpath(filename).open()
+        elif isinstance(filename, HasRead):
             file_object = filename
+        elif isinstance(filename, HasOpen):
+            file_object = filename.open()
         else:
-            # Conversion to handle pathlib on Python < 3.6:
-            file_object = open(str(filename))
+            file_object = open(filename)
 
         with file_object as _f:
             self._to_map = {
                 converters[1](v[name_B]): converters[0](v[name_A])
-                for v in csv.DictReader(l for l in _f if not l.startswith("#"))
+                for v in csv.DictReader(line for line in _f if not line.startswith("#"))
             }
             _f.seek(0)
             self._from_map = {
                 converters[0](v[name_A]): converters[1](v[name_B])
-                for v in csv.DictReader(l for l in _f if not l.startswith("#"))
+                for v in csv.DictReader(line for line in _f if not line.startswith("#"))
             }
 
     @overload
@@ -175,7 +176,7 @@ def DirectionalMaps(name_A, name_B, converters=(str, str), filename=None):
     --------
 
     >>> from particle import data  # doctest: +SKIP
-    >>> filename = data.open_text(data, 'a_to_b.csv')  # doctest: +SKIP
+    >>> filename = data.basepath / "a_to_b.csv"  # doctest: +SKIP
     >>> A2BMap, B2AMap = DirectionalMaps('A', 'B', filename=filename)  # doctest: +SKIP
     """
 
@@ -184,12 +185,13 @@ def DirectionalMaps(name_A, name_B, converters=(str, str), filename=None):
 
     fieldnames = None
     if filename is None:
-        file_object = data.open_text(data, "conversions.csv")
-    elif hasattr(filename, "read"):
+        file_object = data.basepath.joinpath("conversions.csv").open()
+    elif isinstance(filename, HasOpen):
+        file_object = filename.open()
+    elif isinstance(filename, HasRead):
         file_object = filename
     else:
-        # Conversion to handle pathlib on Python < 3.6:
-        file_object = open(str(filename))
+        file_object = open(filename)
 
     with file_object as _f:
         skipinitialspace = True
@@ -197,7 +199,7 @@ def DirectionalMaps(name_A, name_B, converters=(str, str), filename=None):
         to_map = {
             converters[1](v[name_B]): converters[0](v[name_A])
             for v in csv.DictReader(
-                (l for l in _f if not l.startswith("#")),
+                (line for line in _f if not line.startswith("#")),
                 fieldnames=fieldnames,
                 skipinitialspace=skipinitialspace,
             )
@@ -206,7 +208,7 @@ def DirectionalMaps(name_A, name_B, converters=(str, str), filename=None):
         from_map = {
             converters[0](v[name_A]): converters[1](v[name_B])
             for v in csv.DictReader(
-                (l for l in _f if not l.startswith("#")),
+                (line for line in _f if not line.startswith("#")),
                 fieldnames=fieldnames,
                 skipinitialspace=skipinitialspace,
             )
