@@ -7,17 +7,14 @@
 from __future__ import absolute_import
 
 from .. import data
-
 from ..pdgid import PDGID
-
 from .bimap import BiMap, DirectionalMaps
 
-
 EvtGenName2PDGIDBiMap = BiMap(
     PDGID,
     str,
     converters=(int, str),
-    filename=data.open_text(data, "pdgid_to_evtgenname.csv"),
+    filename=data.basepath / "pdgid_to_evtgenname.csv",
 )
 EvtGenName2PDGIDBiMap.__doc__ = """
 Bi-bidirectional map between PDG IDs and EvtGen names.
